@@ -2,7 +2,16 @@ import base64
 
 from . import utility as util
 
+
 class JciHitachiCommand:
+    """Sending job command.
+
+    Parameters
+    ----------
+    gateway_mac_address : str
+        Gateway mac address.
+    """
+
     def __init__(self, gateway_mac_address):
         self.job_info_base = bytearray.fromhex(
                               "d0d100003c6a9dffff03e0d4ffffffff \
@@ -27,17 +36,19 @@ class JciHitachiCommandAC(JciHitachiCommand):
     def get_command(self, command, value):
         job_info = self.job_info_base.copy()
         
-        # command (eg. target_temp)
+        # Command (eg. target_temp)
         job_info[78] = 128 + JciHitachiAC.idx[command]
 
-        # value (eg. 27)
+        # Value (eg. 27)
         job_info[80] = value
 
-        # checksum 
-        # Algorithm: 
-        # 1. command xor value 
-        # 2. flip last 3 bits
-        job_info[81] = job_info[78] ^ job_info[80] ^ 0x7
+        # Checksum 
+        # Original algorithm:
+        # xor job_info 76~80
+        # Since byte 76, 77, and 79 are constants,
+        # here is the simplified algorithm:
+        # command ^ value ^ 0x07 (flip last 3 bits) 
+        job_info[81] = job_info[78] ^ job_info[80] ^ 0x07
 
         assert len(job_info) == 82, \
             "The length of job_info should be 82 bytes."
@@ -47,8 +58,6 @@ class JciHitachiCommandAC(JciHitachiCommand):
 
 class JciHitachiStatusInterpreter:
     def __init__(self, code):
-        #assert len(code) == 92, \
-        #    "The length of code should be 92: {}".format(len(code))
         self.base64_bytes = base64.standard_b64decode(code)
         self.status_number = self._decode_status_number()
 
@@ -92,7 +101,11 @@ class JciHitachiAC:
         'air_speed': 2,
         'target_temp': 3,
         'indoor_temp': 4,
-        'sleep_timer': 6
+        'sleep_timer': 6,
+        'mold_prev': 23,
+        'fast_op': 26,
+        'energy_save': 27,
+        'sound_prompt': 30
     }
 
     def __init__(self, status):
@@ -106,7 +119,11 @@ class JciHitachiAC:
             "air_speed": self.air_speed,
             "target_temp": self.target_temp,
             "indoor_temp": self.indoor_temp,
-            "sleep_timer": self.sleep_timer
+            "sleep_timer": self.sleep_timer,
+            "mold_prev": self.mold_prev,
+            'fast_op': self.fast_op,
+            'energy_save': self.energy_save,
+            'sound_prompt': self.sound_prompt
         }
 
     @property
@@ -153,15 +170,72 @@ class JciHitachiAC:
 
     @property
     def target_temp(self):
+        """Target temperature"""
         v = self._status[JciHitachiAC.idx['target_temp']]
         return v
 
     @property
     def indoor_temp(self):
+        """Indoor temperature"""
         v = self._status[JciHitachiAC.idx['indoor_temp']]
         return v
+    
+    @property
+    def max_temp(self):
+        """Maximum target temperature"""
+        return 32
+    
+    @property
+    def min_temp(self):
+        """Minimum target temperature"""
+        return 16
 
     @property
     def sleep_timer(self):
+        """Sleep timer"""
         v = self._status[JciHitachiAC.idx['sleep_timer']]
         return v
+    
+    @property
+    def mold_prev(self):
+        """Mold prevention"""
+        v = self._status[JciHitachiAC.idx['mold_prev']]
+        if v == 0:
+            return "disabled"
+        elif v == 1:
+            return "enabled"
+        else:
+            return "unknown"
+    
+    @property
+    def fast_op(self):
+        """Fast operation"""
+        v = self._status[JciHitachiAC.idx['fast_op']]
+        if v == 0:
+            return "disabled"
+        elif v == 1:
+            return "enabled"
+        else:
+            return "unknown"
+    
+    @property
+    def energy_save(self):
+        """Energy saving"""
+        v = self._status[JciHitachiAC.idx['energy_save']]
+        if v == 0:
+            return "disabled"
+        elif v == 1:
+            return "enabled"
+        else:
+            return "unknown"
+
+    @property
+    def sound_prompt(self):
+        """Sound prompt"""
+        v = self._status[JciHitachiAC.idx['sound_prompt']]
+        if v == 0:
+            return "enabled"
+        elif v == 1:
+            return "disabled"
+        else:
+            return "unknown"
\ No newline at end of file
