@@ -1,5 +1,4 @@
 import os
-import time
 
 import pytest
 
@@ -11,37 +10,40 @@ TEST_PASSWORD = os.environ['TEST_PASSWORD']
 TEST_DEVICE = os.environ['TEST_DEVICE']
 MOCK_CODE = os.environ["MOCK_CODE"]
 
+TEST_COMMAND = 'sound_prompt'
 
 class TestACStatus:
-    def test_offline(self):
+    def test_ac_offline(self):
         dev_status = JciHitachiStatusInterpreter(MOCK_CODE).decode_status()
         ac_status = JciHitachiAC(dev_status).status
         
         for each_stat in ac_status.values():
             assert each_stat != "unknown" and each_stat != None
 
-    def test_online(self):
+    def test_ac_online(self):
         api = JciHitachiAPI(
             TEST_EMAIL,
             TEST_PASSWORD)
         api.login()
         
-        # Change air speed
-        current_air_speed = api.get_status()[TEST_DEVICE]._status[JciHitachiAC.idx['air_speed']]
-        if current_air_speed != 2:
-            next_air_speed = 2
+        # Change sound prompt
+        current_state = api.get_status()[TEST_DEVICE]._status[JciHitachiAC.idx[TEST_COMMAND]]
+        if current_state != 1:
+            changed_state = 1
         else:
-            next_air_speed = 1
-        assert api.set_status('air_speed', next_air_speed, TEST_DEVICE)
+            changed_state = 0
+        assert api.set_status(TEST_COMMAND, changed_state, TEST_DEVICE)
 
         api.refresh_status() 
-        assert api.get_status()[TEST_DEVICE]._status[JciHitachiAC.idx['air_speed']] == next_air_speed
+        assert api.get_status()[
+            TEST_DEVICE]._status[JciHitachiAC.idx[TEST_COMMAND]] == changed_state
         
-        # Change air speed back
-        assert api.set_status('air_speed', current_air_speed, TEST_DEVICE)
+        # Change sound prompt back
+        assert api.set_status(TEST_COMMAND, current_state, TEST_DEVICE)
         
         api.refresh_status()
-        assert api.get_status()[TEST_DEVICE]._status[JciHitachiAC.idx['air_speed']] == current_air_speed
+        assert api.get_status()[
+            TEST_DEVICE]._status[JciHitachiAC.idx[TEST_COMMAND]] == current_state
 
     #def test_code_length(self):
     #    with pytest.raises(AssertionError):
